package org.jwall.apache.httpd;

import java.io.File;

public interface Apache
{

    /**
     * Returns the file containing the main Apache configuration.
     * 
     * @return The main Apache configuration file.
     */
    public abstract File getHttpdConfig();

    /**
     * This method simply starts the Apache web-server.
     * Right now it just calls <code>apachectl start</code> and checks
     * the return-code.
     * 
     * @throws Exception
     */
    public abstract String start() throws ApacheError, Exception;

    /**
     * Stop the Apache web-server. Simply just a wrapper around
     * <code>apachectl stop</code> with a check of the return-code.
     * 
     * @throws Exception
     */
    public abstract String stop() throws Exception;

    /**
     * Forces a restart the the Apache server. Right now it just calls
     * <code>apachectl restart</code>, but could later send a <i>SIGHUP</i>
     * to the apache process.
     * 
     * @throws Exception
     */
    public abstract void restart() throws Exception;

    /**
     * This method calls the <code>apachectl</code>-script referenced within the ApacheLayout
     * instance by using the <code>configtest</code> feature. Usually this will return a
     * constant string <code>Syntax OK</code> if everything worked fine. Otherwise the exact
     * error message is returned.
     * 
     * @return Status message.
     */
    public abstract String configCheck() throws Exception;

}