package org.jwall.apache.httpd.config;

import java.io.File;
import java.util.LinkedList;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;


/**
 * 
 * This class represents the include directive of Apache.
 * 
 * @author Christian Bockermann &lt;chris@jwall.org&gt;
 *
 */
@XStreamAlias("Include")
public class Include
    extends ContainerDirective
{
    /** The unique class id */
    private static final long serialVersionUID = -3377718126165895115L;
    
    @XStreamAlias("pattern")
    @XStreamAsAttribute
    protected String pattern = "";
    
    
    /**
     * 
     * @param line
     * @param file
     * @param lineNum
     * @throws ParseException
     */
    public Include( String line, File file, int lineNum ) throws ParseException {
        super( line, file, lineNum );
        name = "Include";
        args = new LinkedList<String>();
        String[] token = line.split("\\s+", 2);
        
        if( token.length > 1 )
            for( String param : token[1].split( "\\s+" ) )
                args.add( this.removeQuotes( param ) );
        else
            throw new ParseException("Include-directive must be followed by a path or pattern!");
        
        pattern = args.getFirst();
    }
    
    
    
    /* (non-Javadoc)
     * @see org.apache.httpd.config.ContainerDirective#toPlainTxt()
     */
    @Override
    public String toPlainTxt()
    {
        return rawLine;
    }



    public String toXML(){
        StringBuffer s = new StringBuffer();
        
        s.append( prefix() + "<Include pattern=\"" + args.getFirst() + "\">\n" );
        for( Directive d : nested )
            s.append( d.toXML() );
        
        s.append( prefix() + "</Include>" );
        
        return s.toString();
    }
}