package org.jwall.apache.httpd.config;

import java.io.File;
import java.io.Serializable;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;


/**
 * 
 * This class is just a convenience way for referencing a directive's location.
 * 
 * @author Christian Bockermann &lt;chris@jwall.org&gt;
 *
 */

@XStreamAlias("Location")
public class Position
    implements Serializable, Comparable<Position>
{

    /**
     * 
     */
    private static final long serialVersionUID = 7653352783645893776L;

    @XStreamAsAttribute
    private File file;
    
    @XStreamAlias("line")
    @XStreamAsAttribute
    private Integer lineNum;
    
    
    public Position( File f, Integer line ){
        file = f;
        lineNum = line;
    }


    /**
     * @return the file
     */
    public File getFile()
    {
        return file;
    }


    /**
     * @param file the file to set
     */
    public void setFile(File file)
    {
        this.file = file;
    }


    /**
     * @return the lineNum
     */
    public Integer getLine()
    {
        return lineNum;
    }


    /**
     * @param lineNum the lineNum to set
     */
    public void setLine( Integer lineNum)
    {
        this.lineNum = lineNum;
    }
    
    
    public boolean sameFile( Position other ){
        if( this.file == other.file )
            return true;
        
        return ( file.getAbsolutePath().equals( other.file.getAbsolutePath() ) );
    }
    
    
    public int compareTo( Position other ){
        if( this == other )
            return 0;
        
        if( sameFile( other ) ){
            return lineNum.compareTo( other.lineNum );
        } else {
            return file.getAbsolutePath().compareTo( other.file.getAbsolutePath() );
        }
    }
    
    
    public String toString(){
        return file.getAbsolutePath() + ":" + lineNum;
    }
}