package org.jwall.apache.httpd.config;

import java.io.File;


/**
 * 
 * This class represents the <code>Proxy</code> directive provided by the <code>mod_proxy</code> module.
 * The XML format is similar to the one of the virtual host directive, containing a single attribute
 * <code>address</code> which reflects the unnamed attribute of the Apache proxy directive. 
 * 
 * @author Christian Bockermann &lt;chris@jwall.org&gt;
 *
 */
public class Proxy
    extends ContainerDirective
{
    /** The unique class id */
    private static final long serialVersionUID = -5463425481894979399L;

    
    public Proxy( String line, File file, int lineNum ){
        super( line, file, lineNum );
        name = "Proxy";
    }
    
    public String toXML(){
        StringBuffer s = new StringBuffer();
        
        s.append( prefix() );
        s.append( "<Proxy" );
        if( args.size() > 0 )
            s.append( " address=\"" + args.getFirst() + "\">" );
        
        s.append( "\n" );
        
        for( Directive d : nested )
            s.append( d.toXML() + "\n" );

        s.append( prefix() + "</Proxy>\n" );
        
        return s.toString();
    }
}
