package org.jwall.apache.httpd.config;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

import com.thoughtworks.xstream.annotations.XStreamAlias;


/**
 * <p>
 * Instance of this class represent any <code>SecAction</code> directive found in the configuration tree.
 * </p>
 * 
 * @author Christian Bockermann &lt;chris@jwall.org&gt;
 *
 */
@XStreamAlias("SecAction")
public class SecAction
    extends AbstractDirective
{
    /**      */
    private static final long serialVersionUID = -1435563241845012179L;

    @XStreamAlias("Actions")
    LinkedList<String> actions = new LinkedList<String>();
    
    
    /**
     * 
     * 
     * @param line
     * @param file
     * @param lineNum
     * @throws ParseException
     */
    public SecAction( String line, File file, int lineNum ) throws ParseException {
        super( line, file, lineNum );

        name = "SecAction";
        
        List<String> args = QuotedStringTokenizer.splitRespectQuotes( line.trim(), ' ' ); // line.trim().split(" ");
        
        if( args.isEmpty() || !args.get(0).trim().equals("SecAction"))
            throw new ParseException("Not a SecAction-directive: "+line);
        
        if( args.size() != 2 )
            throw new ParseException( "SecAction needs a single (quoted) string of actions as argument! [" + file.getAbsolutePath() + ":" + lineNum + "]: " + line );
        
        parseActions( removeQuotes( args.get(1) ) );
    }
    
    
    protected void parseActions( String actionString ){
        
        String unquoted = removeQuotes( actionString );
        for( String action : QuotedStringTokenizer.splitRespectQuotes( unquoted , ',' ) ){
            String act = removeQuotes( action.trim() );
            actions.add( act );
        }
    }
    
    
    public String getName(){
        return new String("SecAction");
    }
    
    public String toXML(){
        //return SecRule.xs.toXML( this );

        StringBuffer s = new StringBuffer(prefix()+"<SecAction>\n");
        
        if( actions != null ){
            //s.append( prefix() + "   <Actions>"+actions+"</Actions>\n");
            
            for( String action : actions ){
                s.append( prefix() + "    <Action>" );
                s.append( action  );
                s.append( "</Action>\n" );
            }
        }
        
        s.append(prefix() + "</SecAction>");
        return s.toString();
    }
    
    /**
     * 
     * @return
     */
    public List<String> getActions(){
        return actions;
    }
    
    public String getProviderName(){
        return "mod_security.c";
    }
}