package org.jwall.apache.httpd.service;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.URL;


/**
 * <p>
 * This interface defines an abstract file system layer. 
 * </p>
 * 
 * @author Christian Bockermann &lt;chris@jwall.org&gt;
 *
 */
public interface FileSystem {

	
	public final static int FS_FILE_CREATED = 0;
	public final static int FS_FILE_DELETED = 1;
	public final static int FS_FILE_CHANGED = 2;
	
	
	public String getAbsolutePath( File file );
	
	public boolean exists( File file );
	
	public boolean canRead( File file );
	
	public File[] listFiles( File directory );
	
	public boolean delete( File file ) throws IOException;
	
	public byte[] get( File file ) throws IOException;
	
	public void put( File file, byte[] content ) throws IOException;
	
	public InputStream openInputStream( File file ) throws IOException;
	
	public OutputStream openOutputStream( File file ) throws IOException;
	
	
	/**
	 * Create a copy of the specified within the given destination file system.
	 * The file's path is used as the destination within the target fs.
	 * 
	 * @param file
	 * @param fs
	 * @throws IOException
	 */
	public void copy( File file, FileSystem fs ) throws IOException;

	public void copy( File file, FileSystem targetFs, File targetFile ) throws IOException;
	
	
	public boolean isDirectory( File file );
	
	public boolean createDirectory( File file ) throws IOException;
	
	
	public boolean isSymlink( File file );
	
	public File resolveSymlink( File symlink ) throws IOException;
	
	public String readSymlink( File symlink ) throws IOException;
	
	public void createSymlink( String path, File name ) throws IOException;
	
	
	
	/**
	 * Computes the MD5 checksum of the given file.
	 * 
	 * @param file
	 * @return
	 * @throws IOException
	 */
	public String md5( File file ) throws IOException;

	
	/**
	 * Returns a URL which uniquely identifies the file and the file-system. Usually this
	 * URL contains a schema identifying the file-system implementation, the host on which
	 * the file system resides and the path of the file.
	 * 
	 * @param file
	 * @return
	 */
	public URL getURL( File file );
}