package org.jwall.apache.httpd.service;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.jwall.apache.httpd.config.ApacheConfig;
import org.jwall.apache.httpd.config.ConfigParser;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SshApacheConfigService implements ApacheConfigService {

	static Logger log = LoggerFactory.getLogger( SshApacheConfigService.class );
	SshFileSystem fs;
	
	public SshApacheConfigService( String host, String user, String pass ) throws Exception {
		fs = new SshFileSystem( host, user, pass );
	}
	
	
	
	public ApacheConfig getConfig(String filename) throws Exception {
		ConfigParser p = new ConfigParser( new File( filename ), fs );
		return p.parseConfig();
	}
	

	public boolean putConfig(ApacheConfig config) throws Exception {
		log.info( "Put config... " );
		
		List<ApacheConfig> configs = new ArrayList<ApacheConfig>();
		configs.add( config );
		
		for( ApacheConfig cfg : configs ){
			File out = new File( "/tmp" + cfg.getFile().getAbsolutePath() );
			log.info( "putting {} to {} ", cfg.getFile(), out );
			fs.put( out, cfg.toPlainTxt().getBytes() );
		}
		return false;
	}

	
	public boolean putConfigAll(ApacheConfig config) throws Exception {
		log.info( "Put config... " );
		
		List<ApacheConfig> configs = new ArrayList<ApacheConfig>();
		configs.add( config );
		configs.addAll( config.getSubTrees() );
		
		for( ApacheConfig cfg : configs ){
			File out = new File( "/tmp" + cfg.getFile().getAbsolutePath() );
			log.info( "putting {} to {} ", cfg.getFile(), out );
			fs.put( out, cfg.toPlainTxt().getBytes() );
		}
		return false;
	}
	
	
	public static void main( String[] args ) throws Exception {

		SshApacheConfigService cfg = new SshApacheConfigService( "shuttle.fritz.box", "chris", "p3m4mbit" );
		ApacheConfig c = cfg.getConfig( "/etc/apache2/apache2.conf" );
		log.info( "Config: {}", c.getFile() );
		log.info( "Subtrees: {}", c.getFiles() );
	}
}